@@ -2,7 +2,7 @@ package Bitcoin::Crypto::Key::ExtPublic;
 
 use Modern::Perl "2010";
 use Moo;
-use Digest::SHA qw(hmac_sha512);
+use Crypt::Mac::HMAC qw(hmac);
 use Math::BigInt 1.999816 try => 'GMP';
 use Math::EllipticCurve::Prime;
 use Math::EllipticCurve::Prime::Point;
@@ -28,25 +28,23 @@ sub _derive_key_partial
 	# child number - 4 bytes
 	$hmac_data .= ensure_length pack("N", $child_num), 4;
 
-	my $data = hmac_sha512($hmac_data, $self->chain_code);
+	my $data = hmac("SHA512", $self->chain_code, $hmac_data);
 	my $chain_code = substr $data, 32, 32;
 
 	my $el_curve = Math::EllipticCurve::Prime->from_name($config{curve_name});
 	my $number = Math::BigInt->from_bytes(substr $data, 0, 32);
+	Bitcoin::Crypto::Exception::KeyDerive->raise(
+		"key $child_num in sequence was found invalid"
+	) if $number->bge($el_curve->n);
+
 	my $key = $self->_create_key(substr $data, 0, 32);
 	my $point = Math::EllipticCurve::Prime::Point->from_bytes($key->export_key_raw("public"));
 	$point->curve($el_curve);
 	my $point_cpy = $point->copy();
 	my $parent_point = Math::EllipticCurve::Prime::Point->from_bytes($self->raw_key("public"));
 	$parent_point->curve($el_curve);
-	my $n_order = $el_curve->n;
-
 	$point->badd($parent_point);
 
-	Bitcoin::Crypto::Exception::KeyDerive->raise(
-		"key $child_num in sequence was found invalid"
-	) if $number->bge($n_order);
-
 	return __PACKAGE__->new(
 		$point->to_bytes,
 		$chain_code,
