@@ -1,25 +1,20 @@
 package Bitcoin::Crypto::Role::Key;
 
-our $VERSION = "0.997_01";
-
-use v5.10;
-use warnings;
-use Types::Standard qw(InstanceOf);
+use Modern::Perl "2010";
+use Moo::Role;
+use MooX::Types::MooseLike::Base qw(InstanceOf);
 use Crypt::PK::ECC;
-use Scalar::Util qw(blessed);
 
 use Bitcoin::Crypto::Config;
 use Bitcoin::Crypto::Util qw(get_key_type);
 use Bitcoin::Crypto::Helpers qw(ensure_length);
 use Bitcoin::Crypto::Exception;
-use Moo::Role;
 
 with "Bitcoin::Crypto::Role::Network";
 
 has "key_instance" => (
 	is => "ro",
-	isa => InstanceOf ["Crypt::PK::ECC"],
-	required => 1,
+	isa => InstanceOf["Crypt::PK::ECC"]
 );
 
 sub _is_private { undef }
@@ -51,25 +46,17 @@ sub _create_key
 {
 	my ($class, $entropy) = @_;
 
-	return $entropy
-		if blessed($entropy) && $entropy->isa("Crypt::PK::ECC");
+	my $key_type = get_key_type $entropy;
+	unless (defined $key_type) {
+		Bitcoin::Crypto::Exception::KeyCreate->raise(
+			"invalid entropy data passed to key creation method"
+		) if length $entropy > $config{key_max_length};
 
-	my $is_private = get_key_type $entropy;
-
-	Bitcoin::Crypto::Exception::KeyCreate->raise(
-		"invalid entropy data passed to key creation method"
-	) unless defined $is_private;
-
-	$entropy = ensure_length $entropy, $config{key_max_length}
-		if $is_private;
+		$entropy = ensure_length $entropy, $config{key_max_length};
+	}
 
 	my $key = Crypt::PK::ECC->new();
-
-	Bitcoin::Crypto::Exception::KeyCreate->trap_into(
-		sub {
-			$key->import_key_raw($entropy, $config{curve_name});
-		}
-	);
+	$key->import_key_raw($entropy, $config{curve_name});
 
 	return $key;
 }
@@ -82,8 +69,7 @@ sub raw_key
 		$type = "public_compressed";
 		if ($self->_is_private) {
 			$type = "private";
-		}
-		elsif ($self->does("Bitcoin::Crypto::Role::Compressed") && !$self->compressed) {
+		} elsif ($self->does("Bitcoin::Crypto::Role::Compressed") && !$self->compressed) {
 			$type = "public";
 		}
 	}
